@@ -4,5 +4,5 @@ from H_MCRLLM.mcrllm import *
 from H_MCRLLM.pointselector import * 
 from H_MCRLLM.preprocessing import *
 from H_MCRLLM.select_with_PCA import *
-from H_MCRLLM.use_half_mcr import *
-from H_MCRLLM.use_full_mcr import *
\ No newline at end of file
+from H_MCRLLM.use_half_MCR import *
+from H_MCRLLM.use_full_MCR import *
\ No newline at end of file
