@@ -4,10 +4,10 @@ from H_MCRLLM import half_mcrllm
 def use_half_MCR(X):
 
     # Load all the hierarchical data
-    S_H = np.load('data_H.npy')
+    S_H = np.load('data_S_H.npy')
     
     # Load the reference spectra coming from the PCA (step 2)
-    S = np.load('data_PCA_select.npy')
+    S = np.load('data_PCA_endmembers.npy')
     nb_pure = S.shape[0]
     
     # Center and scale to unit variance
